@@ -165,11 +165,7 @@ class OptionsValues(object):
             new_values = []
             for v in values:
                 option, value = v.split("=", 1)
-                option, value = option.strip(), value.strip()
-                if not value:
-                    raise ConanException("Please define a default value for '%s' in"
-                                         "'default_options'" % option)
-                new_values.append((option, value))
+                new_values.append((option.strip(), value.strip()))
             values = new_values
 
         # handle list of tuples (name, value)
@@ -274,11 +270,7 @@ class OptionsValues(object):
             if not line:
                 continue
             name, value = line.split("=", 1)
-            name, value = name.strip(), value.strip()
-            if not value:
-                raise ConanException("Please define a default value for '%s' in"
-                                     "'default_options'" % name)
-            result.append((name, value))
+            result.append((name.strip(), value.strip()))
         return OptionsValues(result)
 
     @property
